==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authSession/MapAuthenticationSessionEntityFields.java <==
package org.keycloak.models.map.authSession;
public enum MapAuthenticationSessionEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> {
    ACTION {
        public static final String FIELD_NAME = "Action";
        public static final String FIELD_NAME_DASHED = "action";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setAction((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getAction();
        }
    },
    AUTH_NOTES {
        public static final String FIELD_NAME = "AuthNotes";
        public static final String FIELD_NAME_DASHED = "auth-notes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <K> Void mapRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K p0) {
            e.removeAuthNote((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setAuthNotes((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Map<String,String>) e.getAuthNotes();
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K key, T value) {
            e.setAuthNote((String) key, (String) value);
        }
    },
    AUTH_USER_ID {
        public static final String FIELD_NAME = "AuthUserId";
        public static final String FIELD_NAME_DASHED = "auth-user-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setAuthUserId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getAuthUserId();
        }
    },
    CLIENT_NOTES {
        public static final String FIELD_NAME = "ClientNotes";
        public static final String FIELD_NAME_DASHED = "client-notes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K key, T value) {
            e.setClientNote((String) key, (String) value);
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setClientNotes((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <K> Void mapRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K p0) {
            e.removeClientNote((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Map<String,String>) e.getClientNotes();
        }
    },
    CLIENT_SCOPES {
        public static final String FIELD_NAME = "ClientScopes";
        public static final String FIELD_NAME_DASHED = "client-scopes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Set<String>) e.getClientScopes();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setClientScopes((java.util.Set<String>) value);
        }
    },
    CLIENT_UUID {
        public static final String FIELD_NAME = "ClientUUID";
        public static final String FIELD_NAME_DASHED = "client-uuid";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getClientUUID();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setClientUUID((String) value);
        }
    },
    EXECUTION_STATUSES {
        public static final String FIELD_NAME = "ExecutionStatuses";
        public static final String FIELD_NAME_DASHED = "execution-statuses";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setExecutionStatuses((java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus>) e.getExecutionStatuses();
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K key, T value) {
            e.setExecutionStatus((String) key, (org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus) value);
        }
    },
    PROTOCOL {
        public static final String FIELD_NAME = "Protocol";
        public static final String FIELD_NAME_DASHED = "protocol";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getProtocol();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setProtocol((String) value);
        }
    },
    REDIRECT_URI {
        public static final String FIELD_NAME = "RedirectUri";
        public static final String FIELD_NAME_DASHED = "redirect-uri";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getRedirectUri();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setRedirectUri((String) value);
        }
    },
    REQUIRED_ACTIONS {
        public static final String FIELD_NAME = "RequiredActions";
        public static final String FIELD_NAME_DASHED = "required-actions";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void collectionAdd(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.addRequiredAction((String) value);
        }
        @SuppressWarnings("unchecked") @Override public <T> Void collectionRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T p0) {
            e.removeRequiredAction((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Set<String>) e.getRequiredActions();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setRequiredActions((java.util.Set<String>) value);
        }
    },
    TAB_ID {
        public static final String FIELD_NAME = "TabId";
        public static final String FIELD_NAME_DASHED = "tab-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getTabId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setTabId((String) value);
        }
    },
    TIMESTAMP {
        public static final String FIELD_NAME = "Timestamp";
        public static final String FIELD_NAME_DASHED = "timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (Long) e.getTimestamp();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setTimestamp((Long) value);
        }
    },
    USER_SESSION_NOTES {
        public static final String FIELD_NAME = "UserSessionNotes";
        public static final String FIELD_NAME_DASHED = "user-session-notes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Map<String,String>) e.getUserSessionNotes();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setUserSessionNotes((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K key, T value) {
            e.setUserSessionNote((String) key, (String) value);
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/authSession/MapAuthenticationSessionEntityFields.java <==
package org.keycloak.models.map.authSession;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapAuthenticationSessionEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> {
    ACTION {
        public static final String FIELD_NAME = "Action";
        public static final String FIELD_NAME_DASHED = "action";
        public static final String FIELD_NAME_CAMEL_CASE = "action";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getAction();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setAction((String) value);
        }
    },
    AUTH_NOTES {
        public static final String FIELD_NAME = "AuthNotes";
        public static final String FIELD_NAME_DASHED = "auth-notes";
        public static final String FIELD_NAME_CAMEL_CASE = "authNotes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K key, T value) {
            e.setAuthNote((String) key, (String) value);
        }
        @SuppressWarnings("unchecked") @Override public <K> Void mapRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K p0) {
            e.removeAuthNote((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Map<String,String>) e.getAuthNotes();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setAuthNotes((java.util.Map<String,String>) value);
        }
    },
    AUTH_USER_ID {
        public static final String FIELD_NAME = "AuthUserId";
        public static final String FIELD_NAME_DASHED = "auth-user-id";
        public static final String FIELD_NAME_CAMEL_CASE = "authUserId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setAuthUserId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getAuthUserId();
        }
    },
    CLIENT_NOTES {
        public static final String FIELD_NAME = "ClientNotes";
        public static final String FIELD_NAME_DASHED = "client-notes";
        public static final String FIELD_NAME_CAMEL_CASE = "clientNotes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K key, T value) {
            e.setClientNote((String) key, (String) value);
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setClientNotes((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <K> Void mapRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K p0) {
            e.removeClientNote((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Map<String,String>) e.getClientNotes();
        }
    },
    CLIENT_SCOPES {
        public static final String FIELD_NAME = "ClientScopes";
        public static final String FIELD_NAME_DASHED = "client-scopes";
        public static final String FIELD_NAME_CAMEL_CASE = "clientScopes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Set<String>) e.getClientScopes();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setClientScopes((java.util.Set<String>) value);
        }
    },
    CLIENT_UUID {
        public static final String FIELD_NAME = "ClientUUID";
        public static final String FIELD_NAME_DASHED = "client-uuid";
        public static final String FIELD_NAME_CAMEL_CASE = "clientUUID";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getClientUUID();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setClientUUID((String) value);
        }
    },
    EXECUTION_STATUSES {
        public static final String FIELD_NAME = "ExecutionStatuses";
        public static final String FIELD_NAME_DASHED = "execution-statuses";
        public static final String FIELD_NAME_CAMEL_CASE = "executionStatuses";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus.class;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus>) e.getExecutionStatuses();
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K key, T value) {
            e.setExecutionStatus((String) key, (org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus) value);
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setExecutionStatuses((java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus>) value);
        }
    },
    PROTOCOL {
        public static final String FIELD_NAME = "Protocol";
        public static final String FIELD_NAME_DASHED = "protocol";
        public static final String FIELD_NAME_CAMEL_CASE = "protocol";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setProtocol((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getProtocol();
        }
    },
    REDIRECT_URI {
        public static final String FIELD_NAME = "RedirectUri";
        public static final String FIELD_NAME_DASHED = "redirect-uri";
        public static final String FIELD_NAME_CAMEL_CASE = "redirectUri";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setRedirectUri((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getRedirectUri();
        }
    },
    REQUIRED_ACTIONS {
        public static final String FIELD_NAME = "RequiredActions";
        public static final String FIELD_NAME_DASHED = "required-actions";
        public static final String FIELD_NAME_CAMEL_CASE = "requiredActions";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Set<String>) e.getRequiredActions();
        }
        @SuppressWarnings("unchecked") @Override public <T> Void collectionRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T p0) {
            e.removeRequiredAction((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setRequiredActions((java.util.Set<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <T> void collectionAdd(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.addRequiredAction((String) value);
        }
    },
    TAB_ID {
        public static final String FIELD_NAME = "TabId";
        public static final String FIELD_NAME_DASHED = "tab-id";
        public static final String FIELD_NAME_CAMEL_CASE = "tabId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (String) e.getTabId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setTabId((String) value);
        }
    },
    TIMESTAMP {
        public static final String FIELD_NAME = "Timestamp";
        public static final String FIELD_NAME_DASHED = "timestamp";
        public static final String FIELD_NAME_CAMEL_CASE = "timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (Long) e.getTimestamp();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setTimestamp((Long) value);
        }
    },
    USER_SESSION_NOTES {
        public static final String FIELD_NAME = "UserSessionNotes";
        public static final String FIELD_NAME_DASHED = "user-session-notes";
        public static final String FIELD_NAME_CAMEL_CASE = "userSessionNotes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e) {
            return (java.util.Map<String,String>) e.getUserSessionNotes();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, T value) {
            e.setUserSessionNotes((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity e, K key, T value) {
            e.setUserSessionNote((String) key, (String) value);
        }
    },
}
